@@ -8,13 +8,14 @@ pub fn decoder(options: &Options) -> String {
     format!(
         "
 // Decoder
-{decoder_result_blob} {ns}__call(
+{decoder_result_blob} {fn_attributes} {ns}__call(
     {decoder_blob} *self_blob,
     {string_ptr_blob} encoding_blob,
     {byte_list_blob} input_blob);
-void {ns}__drop({decoder_blob} *self_blob);
+void {fn_attributes} {ns}__drop({decoder_blob} *self_blob);
 ",
         ns = ns(),
+        fn_attributes = options.fn_attributes,
         decoder_blob = options.decoder_blob_name,
         decoder_result_blob = options.decoder_result_blob_name,
         string_ptr_blob = options.string_ptr_blob_name,
