@@ -26,18 +26,18 @@ void {fn_attributes} {ns}__diagnostic_message__drop({diagnostic_message_blob} *s
 }
 
 fn constructors(options: &Options) -> String {
-    map_messages_to_sigs(options, &helpers::messages::constructor::sig)
+    map_messages_to_sigs(options, helpers::messages::constructor::sig)
 }
 fn variant_getters(options: &Options) -> String {
-    map_messages_to_sigs(options, &helpers::messages::variant_getter::sig)
+    map_messages_to_sigs(options, helpers::messages::variant_getter::sig)
 }
 fn variant_predicates(options: &Options) -> String {
-    map_messages_to_sigs(options, &helpers::messages::variant_predicate::sig)
+    map_messages_to_sigs(options, helpers::messages::variant_predicate::sig)
 }
 fn field_getters(options: &Options) -> String {
     messages()
-        .flat_map(&|message| {
-            message.fields.map(&|field| {
+        .flat_map(|message| {
+            message.fields.map(|field| {
                 format!(
                     "{signature};",
                     signature = helpers::messages::field_getter::sig(message, field, options)
@@ -47,11 +47,11 @@ fn field_getters(options: &Options) -> String {
         .join("\n")
 }
 
-fn map_messages_to_sigs(
-    options: &Options,
-    sig_fn: &dyn Fn(&Message, &Options) -> String,
-) -> String {
+fn map_messages_to_sigs<F>(options: &Options, sig_fn: F) -> String
+where
+    F: Fn(&Message, &Options) -> String,
+{
     messages()
-        .map(&|message| format!("{sig};", sig = sig_fn(message, options)))
+        .map(|message| format!("{sig};", sig = sig_fn(message, options)))
         .join("\n")
 }
