@@ -14,7 +14,7 @@ pub fn name(message: &Message) -> String {
 fn arglist(message: &Message, options: &Options) -> String {
     message
         .fields
-        .map(&|field| {
+        .map(|field| {
             format!(
                 "{field_type} {field_name}_blob",
                 field_type = fields::field_type(field, options),
