@@ -15,7 +15,8 @@ pub fn name(node: &Node, field: &NodeField) -> String {
 /// Returns C signature of the node field setter for the given `node`/`field` pair
 pub fn sig(node: &Node, field: &NodeField, options: &Options) -> String {
     format!(
-        "void {setter_name}({node_variant_blob}* self_blob, {value_blob_type} {field_name}_blob)",
+        "void {fn_attributes} {setter_name}({node_variant_blob}* self_blob, {value_blob_type} {field_name}_blob)",
+        fn_attributes = options.fn_attributes,
         setter_name = name(node, field),
         node_variant_blob = options.node_variant_blob_name(node),
         value_blob_type = fields::field_type(field, options),
